Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApplicationVisibilities ¶
type ApplicationVisibilities struct {
Application string `xml:"application"`
Default bool `xml:"default"`
Visible bool `xml:"visible"`
}
ApplicationVisibilities is used to tell if an application is visible and defaulted to a Profile.
type ClassAccesses ¶
ClassAccesses is used to tell if a Apex Class is visible for some Profile
type FieldPermissions ¶
type FieldPermissions struct {
Field string `xml:"field"`
Editable bool `xml:"editable"`
Readable bool `xml:"readable"`
}
FieldPermissions is used to store field permissions for this Profile.
type FlowAccesses ¶
FlowAccesses is used to tell if a flow is visible to a Profile
type LayoutAssignments ¶
type LayoutAssignments struct {
Layout string `xml:"layout"`
}
LayoutAssignments is used to tell if a Layout is specified for a Profile
type LoginIPRanges ¶
type LoginIPRanges struct {
EndAddress string `xml:"endAddress"`
StartAddress string `xml:"startAddress"`
}
LoginIPRanges is used to specify an available IP range for a specific Profile.
type ObjectPermissions ¶
type ObjectPermissions struct {
Object string `xml:"object"`
AllowCreate bool `xml:"allowCreate"`
AllowDelete bool `xml:"allowDelete"`
AllowEdit bool `xml:"allowEdit"`
AllowRead bool `xml:"allowRead"`
ModifyAllRecords bool `xml:"modifyAllRecords"`
ViewAllRecords bool `xml:"viewAllRecords"`
}
ObjectPermissions is used to store a list of permissions for a SObject.
type PageAccesses ¶
PageAccesses is used to specify the accessibility of a Visualforce Page.
type RecordTypeVisibilities ¶
type RecordTypeVisibilities struct {
RecordType string `xml:"recordType"`
Default bool `xml:"default"`
Visible bool `xml:"visible"`
}
RecordTypeVisibilities is used to specify the properties of a Record Type.
type TabVisibilities ¶
TabVisibilities is used to store visibilities for Tabs
type UserLicense ¶
type UserLicense string
UserLicense is used to tell what user license is used for this Profile
type UserPermissions ¶
UserPermissions is used to store User Permissions specified for the Profile.